pub struct DateRangeArgs { /* private fields */ }Expand description
Representation of the start and end date arguments for reports.
Implementations
Sourceimpl DateRangeArgs
impl DateRangeArgs
Sourcepub fn new(dates: &[String]) -> Result<Self>
pub fn new(dates: &[String]) -> Result<Self>
Create the DateRangeArgs from an array of strings.
Errors
- Return
Error::DateErrorif the start date is not before the end date