initialize

Function initialize 

pub fn initialize(config: &Config, dir: Option<&str>) -> Result<(), PathError>
Initialize the timelog directory supplied and create a .timelogrc config file. If no directory is supplied default to ~/timelog

Errors

Panics

If the canonicalized path cannot be converted to a string.